// Copyright (c) 2015, Will Squire. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

library functional_behaviour_tree.composite.sequence;

import '../node.dart';
import '../composite.dart';
import 'dart:async';

/// The sequence composite processes an array of nodes that it iterates through. Along the way, the sequence node will stop its iterating processing of internal nodes if any node returns false. If any node returns false, the sequence returns false.
/// The sequence will return true if the processing of the internal array reaches the end without any of the nodes returning false; thus completing the sequence.
Composite sequence = (Map blackboard, List<Node> nodes) async {
  for(Node node in nodes) {
    if (!await node(blackboard))
      return new Future(() => false);
  }
  return new Future(() => true);
};